test_function <- function(params) {
  return(params[[1]] + params[[2]])
}
